function v=compute_ekman_surge_eexp(vmax,rmax,r35,vt,phi,phi_in,w,a,n,lat)
% Computes ekman_surge_eexp
% Script automatically generated by fit_ekman_surge_eexp.m
% Inputs : 
% vmax           = Vmax (km/h)
% rmax           = Rmax (km)
% r35            = R35 (km)
% vt             = forward speed (km/h)
% phi            = track angle (deg)
% phi_in         = inflow angle (deg)
% w              = shelf width (km)
% a              = Dean slope a (-)
% n              = Mannings n
% lat            = latitude (deg)

% R2    = 0.73051
% RMSE  = 0.11163
% MEAN  = -0.10087
% RANGE = -0.4547 - 0.35912

beta( 1 )= -6.6882e-01 ;
beta( 2 )= 8.1304e-01 ;
beta( 3 )= 1.4592e+02 ;
beta( 4 )= -3.7333e+00 ;
beta( 5 )= 8.8043e-03 ;
beta( 6 )= -8.4567e-03 ;
beta( 7 )= 4.4744e-04 ;
beta( 8 )= 7.9048e-03 ;
beta( 9 )= 1.6729e-01 ;
beta( 10 )= 2.0512e-01 ;

v=beta(1) + beta(2)*exp(-w/beta(3)) + beta(4)*a + beta(5)*vt + beta(6)*lat + beta(7)*r35 + beta(8)*phi_in + beta(9).*sin(phi*pi/180);
